| f_arrange | R Documentation |
collapse version of dplyr::arrange()This is a fast and near-identical alternative to dplyr::arrange()
using the collapse package.
desc() is like dplyr::desc() but works faster when
called directly on vectors.
f_arrange(
.data,
...,
.by = NULL,
.by_group = FALSE,
.cols = NULL,
.descending = FALSE,
.in_place = FALSE
)
.data |
A data frame. |
... |
Variables to arrange by. |
.by |
(Optional). A selection of columns to group by for this operation.
Columns are specified using |
.by_group |
If |
.cols |
(Optional) alternative to |
.descending |
|
.in_place |
Should data be sorted in-place?
This can be very efficient for large data frames and can be safely used
when overwriting a freshly allocated data frame.
If you're unsure whether the data frame is a freshly allocated object,
use Please note that no new vectors and no copies are created, data is directly sorted in-memory. This only works on data frames consisting of atomic vectors. |
A sorted data.frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.