| f_expand | R Documentation |
tidyr::expand() and tidyr::complete().Fast versions of tidyr::expand() and tidyr::complete().
f_expand(.data, ..., .sort = FALSE, .by = NULL, .cols = NULL)
f_complete(.data, ..., .sort = FALSE, .by = NULL, .cols = NULL, fill = NA)
crossing(..., .sort = FALSE)
nesting(..., .sort = FALSE)
.data |
A data frame |
... |
Variables to expand. |
.sort |
Logical. If |
.by |
(Optional). A selection of columns to group by for this operation. Columns are specified using tidy-select. |
.cols |
(Optional) alternative to |
fill |
A named list containing value-name pairs to fill the named implicit missing values. |
crossing and nesting are helpers that are basically identical to
tidyr's crossing and nesting.
A data.frame of expanded groups.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.